# Node.js Modules
The library provides interoperability with the following [Node.js](https://nodejs.org) core modules:

## The [globals](https://nodejs.org/api/globals.html) module
This module provides objects that are available globally:

```dart
print(dirname); // "/path/to"
print(filename); // "app.dart.js"
print(module.id); // "/path/to/app.dart.js"

print(process.arch); // "x64"
print(process.platform); // "linux"
```

## The [`assert`](https://nodejs.org/api/assert.html) module
This module provides a simple set of assertion tests that can be used to test invariants:

```dart
AssertModule _assert = require('assert');

_assert(true); // Returns normally.
_assert(false); // Throws a `JSAssertionError`.
```

## The [`buffer`](https://nodejs.org/api/buffer.html) module
This module provides the global `Buffer` class and related utilities:

```dart
var buffer = Buffer.from('hello world', BufferEncoding.ascii);

print(buffer.toString(BufferEncoding.hex)); // "68656c6c6f20776f726c64"
print(buffer.toString(BufferEncoding.base64)); // "aGVsbG8gd29ybGQ="
```

## The [`child_process`](https://nodejs.org/api/child_process.html) module
This module provides the ability to spawn child processes:

```dart
ChildProcessModule childProcess = require('child_process');

var callback = allowInterop((error, stdout, stderr) => print(stdout));
childProcess.exec('cat *.dart | wc -l', callback);
```

## The [`cluster`](https://nodejs.org/api/cluster.html) module
This module allows easy creation of child processes that all share server ports:

```dart
ClusterModule cluster = require('cluster');

TODO
```

## The [`console`](https://nodejs.org/api/console.html) module
This module allows easy creation of child processes that all share server ports:

```dart
TODO
```

## The [`dns`](https://nodejs.org/api/dns.html) module
This module allows easy creation of child processes that all share server ports:

```dart
DnsModule cluster = require('dns');

TODO
```

## The [`events`](https://nodejs.org/api/events.html) module
This module provides the `EventEmitter` class:

```dart
// Required: the `EventEmitter` class doesn't exist before this call.
loadLibrary('events');

var listener = allowInterop((data) => print('A "eventName" event occurred: ${data['foo']}'));
var emitter = new EventEmitter()..on('eventName', listener);
emitter.emit('eventName', new JsObject.jsify({'foo': 'bar'}));
```

## The [`fs`](https://nodejs.org/api/fs.html) module
This module allows easy creation of child processes that all share server ports:

```dart
DnsModule cluster = require('dns');

TODO
```

## The [`os`](https://nodejs.org/api/os.html) module
This module provides a number of operating system-related utility methods:

```dart
OSModule os = require('os');

print(os.homedir()); // "/home/user"
print(os.tmpdir()); // "/tmp"
```

## The [`path`](https://nodejs.org/api/path.html) module
This module provides utilities for working with file and directory paths:

```dart
PathModule path = require('path');

print(path.basename('/foo/bar/baz.txt')); // "baz.txt"
print(path.dirname('/foo/bar/baz.txt')); // "/foo/bar"
```

## The [`querystring`](https://nodejs.org/api/querystring.html) module
This module provides utilities for working with file and directory paths:

```dart
QueryStringModule querystring = require('querystring');

TODO
```
