/// Provides interoperability with [`dns`](https://nodejs.org/api/dns.html) module.
@JS()
library nodejs_interop.node.dns;

import 'package:js/js.dart';
import 'package:nodejs_interop/js.dart';

part 'dns/options.dart';
part 'dns/records.dart';
part 'dns/resolver.dart';

/// The [`dns`](https://nodejs.org/api/dns.html) module.
@JS()
abstract class DnsModule implements _Resolver {

  /// Flag indicating that returned address types are determined by the types of addresses supported by the current system.
  /// For example, IPv4 addresses are only returned if the current system has at least one IPv4 address configured.
  /// Loopback addresses are not considered.
  external int get ADDRCONFIG;

  /// Flag indicating whether to return IPv4 mapped IPv6 addresses when a IPv6 family was specified but no IPv6 addresses were found.
  external int get V4MAPPED;

  /// Resolves a [hostname] into the first found `A` (IPv4) or `AAAA` (IPv6) record.
  ///
  /// All `options` properties are optional. If `options` is an integer, then it must be `4` or `6`.
  /// If `options` is not provided, then IPv4 and IPv6 addresses are both returned if found.
  ///
  /// With the `all` option set to true, the arguments for callback change to `(err, addresses)`,
  /// with `addresses` being a list of objects with the properties `address` and `family`.
  external void lookup(String hostname, [optionsOrCallback, CompletionCallback2<String, int> callback]);

  /// Resolves the given [address] and [port] into a `hostname` and `service` using
  /// the operating system's underlying [`getnameinfo`](http://manpages.ubuntu.com/manpages/xenial/en/man3/getnameinfo.3.html) implementation.
  external void lookupService(String address, int port, CompletionCallback2<String, String> callback);
}
