part of nodejs_interop.node.dns;

/// Options used to customize a DNS lookup.
@JS()
@anonymous
class LookupOptions {

  /// Creates a new path object.
  external factory LookupOptions({
    bool all = false,
    int family,
    int hints,
    bool verbatim = false
  });

  /// Value indicating whether to the callback receives all resolved addresses in a list, instead of a single address.
  external bool get all;
  external set all(bool value);

  /// The record family. Must be `4` or `6`. IPv4 and IPv6 addresses are both returned by default.
  external int get family;
  external set family(int value);

  /// One or more supported [`getaddrinfo`](http://manpages.ubuntu.com/manpages/xenial/en/man3/getaddrinfo.3.html) flags.
  external int get hints;
  external set hints(int value);

  /// Value indicating whether the callback receives IPv4 and IPv6 addresses
  /// in the order the DNS resolver returned them, instead of reordering them.
  external bool get verbatim;
  external set verbatim(bool value);
}

/// Options used to customize the resolution of a hostname.
@JS()
@anonymous
class ResolveOptions {

  /// Creates a new path object.
  external factory ResolveOptions({bool ttl = false});

  /// Value indicating whether to retrieve the Time-To-Live value (TTL), expressed in seconds, of each record.
  external bool get ttl;
  external set ttl(bool value);
}
