/// Provides interoperability with [`string_decoder`](https://nodejs.org/api/string_decoder.html) module.
@JS()
library nodejs_interop.node.string_decoder;

import 'package:js/js.dart';
import 'package:nodejs_interop/src/node/buffer.dart';

/// Decodes [Buffer] objects into strings in a manner that preserves encoded multi-byte UTF-8 and UTF-16 characters.
@JS(r'$string_decoder.StringDecoder')
class StringDecoder {

  /// Creates a new string decoder.
  external factory StringDecoder([String encoding = BufferEncoding.utf8]);

  /// Returns any remaining input stored in the internal buffer as a string.
  /// Bytes representing incomplete UTF-8 and UTF-16 characters will be replaced with substitution characters appropriate for the character encoding.
  ///
  /// If the [buffer] argument is provided, one final call to [write] is performed before returning the remaining input.
  external String end([Buffer buffer]);

  /// Returns a decoded string, ensuring that any incomplete multibyte characters at the end of the [buffer] are omitted from the returned string
  /// and stored in an internal buffer for the next call to [write] or [end].
  external String write(Buffer buffer);
}
