/// Provides a [Pub](https://pub.dartlang.org) transformer for [Node.js](https://nodejs.org) applications.
library nodejs_interop.pub;

import 'dart:async';
import 'package:barback/barback.dart';
import 'package:node_preamble/preamble.dart';

/// Adds a [Node.js](https://nodejs.org) preamble to a [dart2js](https://webdev.dartlang.org/tools/dart2js) asset.
class NodeTransformer extends Transformer {

  /// The transformer settings.
  final BarbackSettings _settings;

  /// Creates a new transformer.
  NodeTransformer.asPlugin(this._settings);

  /// A space-separated list of file extensions that are allowed for the primary inputs to this transformer.
  @override
  String get allowedExtensions => '.dart.js';

  /// Run this transformer on the primary input specified by [transform].
  @override
  Future<Null> apply(Transform transform) async {
    var input = await transform.primaryInput.readAsString();
    var output = '${getPreamble(minified: _settings.mode == BarbackMode.RELEASE)}\n$input';
    var shebang = _settings.configuration['shebang'] ?? false;
    transform.addOutput(new Asset.fromString(transform.primaryInput.id, shebang ? '#!/usr/bin/env node\n$output' : output));
  }
}
